import random
import turtle

# Original Monte Carlo Pi method adapted to computing 1/4
def quarterCalc(numDarts):
    inRegion = 0       
    for i in range(numDarts):
        x = random.random() # returns a number [0, 1)
        y = random.random()
        
        # determining inside region is simpler
        # concept is the same
        if x <= 0.5 and y <= 0.5:
            inRegion = inRegion + 1
    fraction = inRegion/numDarts
    return fraction

# displays the algorithm graphically
def showQuarterCalc(numDarts):
    wn = turtle.Screen()
    wn.bgcolor("light green")
    wn.setworldcoordinates(0,0,2,2)

    drawingT = turtle.Turtle()

    #draws x-axis
    drawingT.up()
    drawingT.goto(0,0)
    drawingT.down()
    drawingT.goto(1,0)

    #draw y-axis
    drawingT.up()
    drawingT.goto(0,1)
    drawingT.down()
    drawingT.goto(0,0)
    
    #draws quarter-sized square
    drawingT.up()
    drawingT.goto(0,0.5)
    drawingT.down()
    drawingT.goto(0.5,0.5)
    drawingT.goto(0.5,0)
    
    #draws full-sized square
    drawingT.up()
    drawingT.goto(0,1)
    drawingT.down()
    drawingT.goto(1,1)
    drawingT.goto(1,0)

    # runs loop to generate and count inside darts
    inRegion = 0
    drawingT.up()
    turtle.tracer(10,1) # tell turtle module to update display quickly
    
    for i in range(numDarts):
        x = random.random()
        y = random.random()
        
        drawingT.goto(x,y)
        if x <= 0.5 and y <= 0.5:
            inRegion = inRegion + 1
            drawingT.color("blue")
        else:
            drawingT.color("red")            
        drawingT.dot()
        
    fraction = inRegion/numDarts
    return fraction

# Animates the algorithm and plots the real-time estimation
# of the 1/4 calculation
def showQuarterCalcGraph(numDarts):
    wn = turtle.Screen()
    wn.bgcolor("light green")
    wn.setworldcoordinates(0,0,2,2)

    drawingT = turtle.Turtle()
    # draws x-axis for lower left region
    drawingT.up()
    drawingT.goto(0,0)
    drawingT.down()
    drawingT.goto(1,0)

    # draws y-axis for the lower left region
    drawingT.up()
    drawingT.goto(0,1)
    drawingT.down()
    drawingT.goto(0,0)
    
    # draws quarter-sized sqaure
    drawingT.up()
    drawingT.goto(0,0.5)
    drawingT.down()
    drawingT.goto(0.5,0.5)
    drawingT.goto(0.5,0)
    drawingT.up()
    #Draws full-sized square
    drawingT.goto(0,1)
    drawingT.down()
    drawingT.goto(1,1)
    drawingT.goto(1,0)

    # draws x-axis for upper right region
    drawingT.up()
    drawingT.goto(1,1)
    drawingT.down()
    drawingT.goto(2,1)
    drawingT.up()
    # draws y-axis for upper right region
    drawingT.goto(1,2)
    drawingT.down()
    drawingT.goto(1,1)
    
    # plots the line for 1/4 in red on the upper right graph
    drawingT.up()
    drawingT.color("red")
    drawingT.goto(1, 1.25)
    drawingT.down()
    drawingT.goto(2, 1.25)
    drawingT.up()

    inRegion = 0
    drawingT.up()
    turtle.tracer(10,1) # tell turtle module to update display quickly
    
    for i in range(numDarts):
        x = random.random()
        y = random.random()
        
        drawingT.goto(x,y)
        if x<=0.5 and y<=0.5:
            inRegion = inRegion + 1
            drawingT.color("blue")
        else:
            drawingT.color("red")            
        drawingT.dot()
        
        #draws the real-time approximation of 1/4 on the upper right graph
        if i > 0:
            drawingT.color("black")
            drawingT.up()
            drawingT.goto((1+i/numDarts), 1+(inRegion/i))
            drawingT.down()
            drawingT.dot()
            drawingT.up()
        
        
    fraction = inRegion/numDarts
    return fraction



#print(quarterCalc(500))
#print(showQuarterCalc(1000))
print(showQuarterCalcGraph(1500))



